# generate tree maps for various genomes
# 2019-10-07 by WRF

library(treemap)
library(grid)

#colset = c("#fcfbfd", "#efedf5", "#dadaeb", "#bcbddc", "#9e9ac8", "#807dba", "#6a51a3", "#54278f", "#3f007d")


em_colset = colorRampPalette(c("#081d58","#addd8e"))(18)

emu1_file = "~/genomes/ephydatia_muelleri/treemap/renumbered_final_nb.sizes"
emu1_data = read.table(emu1_file, sep="\t")

em_contig_lengths = emu1_data[["V2"]]
em_sum = sum(em_contig_lengths)
em_sum
em_log_contigs = floor(log(em_contig_lengths))
em_log_contigs
emu1_cols = em_colset[em_log_contigs]
emu1_data_w_cols = data.frame(emu1_data, emu1_cols)

pdf("~/genomes/ephydatia_muelleri/treemap/emu1_treemap.pdf", width=7, height=7)
treemap(emu1_data_w_cols, index=c("V1"), vSize=c("V2"), vColor=c("emu1_cols"), type="color", title="Ephydatia scaffold sizes" )

dev.off()

#
# Amphimedon queenslandica
#
aq_colset = colorRampPalette(c("#fcfbfd","#3f007d"))(9)

aqu1_file = "~/genomes/ephydatia_muelleri/treemap/Amphimedon_queenslandica.Aqu1.dna.toplevel.sizes"
aqu1_data = read.table(aqu1_file, sep="\t")
head(aqu1_data)
aq_contig_lengths = aqu1_data[["V2"]]
aq_sum = sum(aq_contig_lengths)
aq_sum
aq_log_contigs = floor(log(aq_contig_lengths))-5
range(aq_log_contigs)

acn = gsub("Contig(\\d+)", "\\1", aqu1_data[["V1"]], perl=TRUE)
aqu1_cols = aq_colset[aq_log_contigs]
aqu1_data_w_cols = data.frame(acn, aq_contig_lengths, aqu1_cols)
head(aqu1_data_w_cols)

pdf("~/genomes/ephydatia_muelleri/treemap/aqu1_treemap.pdf", width=7, height=7)
treemap(aqu1_data_w_cols, index=c("acn"), vSize=c("aq_contig_lengths"), vColor=c("aqu1_cols"), type="color", title="Amphimedon scaffold sizes" )
dev.off()




#
# Sycon ciliatum
#

sc_colset = colorRampPalette(c("#fcfbfd","#7d003f"))(10)

scil1_file = "~/genomes/ephydatia_muelleri/treemap/sycon.genome.sizes"
scil1_data = read.table(scil1_file, sep="\t")

sc_contig_lengths = scil1_data[["V2"]]
sc_sum = sum(sc_contig_lengths)
sc_sum
sc_log_contigs = floor(log(sc_contig_lengths))-5
range(sc_log_contigs)

scil1_cols = sc_colset[sc_log_contigs]
scil1_data_w_cols = data.frame(scil1_data, scil1_cols)

pdf("~/genomes/ephydatia_muelleri/treemap/scil1_treemap.pdf", width=7, height=7)
treemap(scil1_data_w_cols, index=c("V1"), vSize=c("V2"), vColor=c("scil1_cols"), type="color", title="Sycon scaffold sizes" )
dev.off()


#
# Tethya wilhelma
#

tw_colset = colorRampPalette(c("#fcfbfd","#993404"))(9)

twi1_file = "~/genomes/ephydatia_muelleri/treemap/twilhelma_scaffolds_v1.sizes"
twi1_data = read.table(twi1_file, sep="\t")
head(twi1_data)
twi1_contig_lengths = twi1_data[["V2"]]
tw_sum = sum(twi1_contig_lengths)
tw_sum
twi1_log_contigs = floor(log(twi1_contig_lengths))-5
range(twi1_log_contigs)

twi1_cols = tw_colset[twi1_log_contigs]
tcn = gsub("twilhelma_v1_(\\d+)_len.*", "\\1", twi1_data[["V1"]], perl=TRUE)
twi1_data_w_cols = data.frame(tcn, twi1_contig_lengths, twi1_cols)
head(twi1_data_w_cols)

pdf("~/genomes/ephydatia_muelleri/treemap/twi1_treemap.pdf", width=7, height=7)
treemap(twi1_data_w_cols, index=c("tcn"), vSize=c("twi1_contig_lengths"), vColor=c("twi1_cols"), type="color", title="Tethya scaffold sizes" )
dev.off()


pdf("~/genomes/ephydatia_muelleri/treemap/sponge_combined_treemaps_v1.pdf", width=8, height=9)
vplayout <- function(x, y) viewport(layout.pos.row = x, layout.pos.col = y)
grid.newpage()
pushViewport(viewport(layout = grid.layout(2,2)))
treemap(emu1_data_w_cols, index=c("V1"), vSize=c("V2"), vColor=c("emu1_cols"), type="color", title="Ephydatia scaffold sizes", vp=vplayout(1,1) )
treemap(aqu1_data_w_cols, index=c("acn"), vSize=c("aq_contig_lengths"), vColor=c("aqu1_cols"), type="color", title="Amphimedon scaffold sizes", vp=vplayout(1,2) )
treemap(twi1_data_w_cols, index=c("tcn"), vSize=c("twi1_contig_lengths"), vColor=c("twi1_cols"), type="color", title="Tethya scaffold sizes", vp=vplayout(2,1) )
treemap(scil1_data_w_cols, index=c("V1"), vSize=c("V2"), vColor=c("scil1_cols"), type="color", title="Sycon scaffold sizes", vp=vplayout(2,2)  )
dev.off()


# size in pixels of ephydatia grid
sqrt(em_sum/sc_sum)*326.450
# size of amphimedon
sqrt(aq_sum/sc_sum)*326.450
# size of tethya
sqrt(tw_sum/sc_sum)*326.450
# sycon is largest, so change nothing







hm_colset = colorRampPalette(c("#fcfbfd","#0868ac"))(10)

hm_file = "~/genomes/ephydatia_muelleri/treemap/Hm105_Dovetail_Assembly_1.0.sizes"
hm_data = read.table(hm_file, sep="\t")
head(hm_data)
hm_contig_lengths = hm_data[["V2"]]
hm_sum = sum(hm_contig_lengths)
hm_sum

hm_log_contigs = floor(log(hm_contig_lengths))-5
range(hm_log_contigs)

hm_cols = hm_colset[hm_log_contigs]
hm_cn = gsub("Sc4wPfr_(.+)", "\\1", hm_data[["V1"]], perl=TRUE)
hm_data_w_cols = data.frame(hm_cn, hm_contig_lengths, hm_cols)
head(hm_data_w_cols)

pdf("~/genomes/ephydatia_muelleri/treemap/hm_dovetail_treemap.pdf", width=7, height=7)
treemap(hm_data_w_cols, index=c("hm_cn"), vSize=c("hm_contig_lengths"), vColor=c("hm_cols"), type="color", title=paste("Hydra magnipapillata v2",round(hm_sum/1000000,digits=1),"Mb") )
dev.off()










#